@@ -22,7 +22,7 @@ pub fn evaluate_expr(
     Calcit::Number(_) => Ok(expr.clone()),
     Calcit::Symbol(s, ..) if s == "&" => Ok(expr.clone()),
     Calcit::Symbol(s, ns, resolved) => match resolved {
-      Some(ResolvedDef(r_ns, r_def)) => {
+      Some(ResolvedDef(r_ns, r_def, _import_rule)) => {
         let v = evaluate_symbol(&r_def, scope, &r_ns, program_code)?;
         match v {
           // extra check to make sure thunks extracted
@@ -67,7 +67,10 @@ pub fn evaluate_expr(
             run_fn(&values, &def_scope, args, body, def_ns, program_code)
           }
           Calcit::Macro(name, def_ns, _, args, body) => {
-            println!("[Warn] macro should already be handled during preprocessing: {}", x);
+            println!(
+              "[Warn] macro should already be handled during preprocessing: {}",
+              Calcit::List(xs.to_owned()).lisp_str()
+            );
 
             // TODO moving to preprocess
             let mut current_values = rest_nodes.clone();
